==> v1.91.tar.gz: chrono/chrono/utils/spooler.py <==
# -*- coding: utf-8 -*-
# chrono - agendas system
# Copyright (C) 2021  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.db import connection
from uwsgidecorators import spool

from chrono.agendas.models import ICSError, TimePeriodExceptionSource


def set_connection(domain):
    from hobo.multitenant.middleware import TenantMiddleware

    tenant = TenantMiddleware.get_tenant_by_hostname(domain)
    connection.set_tenant(tenant)


@spool
def refresh_exception_source(args):
    if args.get('domain'):
        # multitenant installation
        set_connection(args['domain'])

    try:
        source = TimePeriodExceptionSource.objects.get(pk=args['source_id'])
    except TimePeriodExceptionSource.DoesNotExist:
        return
    try:
        source.refresh_timeperiod_exceptions_from_ics()
    except ICSError:
        pass


@spool
def refresh_exceptions_from_settings(args):
    if args.get('domain'):
        # multitenant installation
        set_connection(args['domain'])

    try:
        source = TimePeriodExceptionSource.objects.get(pk=args['source_id'])
    except TimePeriodExceptionSource.DoesNotExist:
        return

    source.refresh_from_settings()

==> v2.59.tar.gz: chrono/chrono/utils/spooler.py <==
# chrono - agendas system
# Copyright (C) 2021  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.db import connection
from uwsgidecorators import spool  # pylint: disable=import-error

from chrono.agendas.models import ICSError, TimePeriodExceptionSource


def set_connection(domain):
    from hobo.multitenant.middleware import TenantMiddleware  # pylint: disable=import-error

    tenant = TenantMiddleware.get_tenant_by_hostname(domain)
    connection.set_tenant(tenant)


@spool
def refresh_exception_source(args):
    if args.get('domain'):
        # multitenant installation
        set_connection(args['domain'])

    try:
        source = TimePeriodExceptionSource.objects.get(pk=args['source_id'])
    except TimePeriodExceptionSource.DoesNotExist:
        return
    try:
        source.refresh_timeperiod_exceptions_from_ics()
    except ICSError:
        pass


@spool
def refresh_exceptions_from_settings(args):
    if args.get('domain'):
        # multitenant installation
        set_connection(args['domain'])

    try:
        source = TimePeriodExceptionSource.objects.get(pk=args['source_id'])
    except TimePeriodExceptionSource.DoesNotExist:
        return

    source.refresh_from_settings()
